W5100, SD card, DS18B20

Dependencies:   LinkedList

Fork of DS1820 by Erik -

Revision:
7:58b61681818f
Parent:
6:abfdd851218a
--- a/DS1820.h	Wed Apr 02 19:10:34 2014 +0000
+++ b/DS1820.h	Tue Apr 08 09:59:18 2014 +0000
@@ -54,6 +54,10 @@
     enum devices{
         this_device,     // command applies to only this device
         all_devices };   // command applies to all devices
+    
+    enum {
+        invalid_conversion = -1000
+    };
 
     /** Create a probe object connected to the specified pins
     *
@@ -91,7 +95,7 @@
       * probe to read its RAM, do CRC check and convert temperature on the LPC1768.
       *
       * @param scale, may be either 'c' or 'f'
       * @returns temperature for that scale, or -1000.0 if CRC error detected.
       */
     float temperature(char scale='c');
@@ -91,7 +95,7 @@
       *
       * @param scale, may be either 'c' or 'f'
-      * @returns temperature for that scale, or -1000.0 if CRC error detected.
+      * @returns temperature for that scale, or DS1820::invalid_conversion (-1000) if CRC error detected.
       */
     float temperature(char scale='c');